@@ -1,5 +1,4 @@
 import contextlib
-import time
 from io import BytesIO
 from tempfile import TemporaryFile
 
@@ -16,18 +15,18 @@ def generate_sample_data():
         name=String._type, encoding="ros1msg", data=String._full_text.encode()  # type: ignore
     )
     string_channel_id = writer.register_channel(
-        topic="chatter", message_encoding="ros1", schema_id=string_schema_id
+        topic="/chatter", message_encoding="ros1", schema_id=string_schema_id
     )
 
-    for i in range(1, 11):
+    for i in range(10):
         s = String(data=f"string message {i}")
         buff = BytesIO()
         s.serialize(buff)  # type: ignore
         writer.add_message(
             channel_id=string_channel_id,
-            log_time=time.time_ns(),
+            log_time=i * 1000,
             data=buff.getvalue(),
-            publish_time=time.time_ns(),
+            publish_time=i * 1000,
         )
     writer.finish()
     file.seek(0)
